@@ -12,7 +12,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "mainwindow.h"
@@ -45,7 +45,8 @@ MainWindow::~MainWindow()
 void MainWindow::init()
 {
     QWidget* viewWidget = QWidget::createWindowContainer(m_view, this);
-    viewWidget->setMinimumSize(1000, 700);
+    const int unit = fontMetrics().height();
+    viewWidget->setMinimumSize(56 * unit, 39 * unit);
     viewWidget->setFocusPolicy(Qt::StrongFocus);
     setCentralWidget(viewWidget);
 
